@@ -1,20 +1,25 @@
 from __future__ import absolute_import
-
 import logging
-import requests
 
+import requests
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['cloudns.net']
 
+
 def ProviderParser(subparser):
     identity_group = subparser.add_mutually_exclusive_group()
-    identity_group.add_argument("--auth-id", help="specify user id for authentication")
-    identity_group.add_argument("--auth-subid", help="specify subuser id for authentication")
-    identity_group.add_argument("--auth-subuser", help="specify subuser name for authentication")
-    subparser.add_argument("--auth-password", help="specify password for authentication")
+    identity_group.add_argument(
+        "--auth-id", help="specify user id for authentication")
+    identity_group.add_argument(
+        "--auth-subid", help="specify subuser id for authentication")
+    identity_group.add_argument(
+        "--auth-subuser", help="specify subuser name for authentication")
+    subparser.add_argument(
+        "--auth-password", help="specify password for authentication")
     subparser.add_argument("--weight", help="specify the SRV record weight")
     subparser.add_argument("--port", help="specify the SRV record port")
 
@@ -26,9 +31,10 @@ class Provider(BaseProvider):
         self.api_endpoint = 'https://api.cloudns.net'
 
     def authenticate(self):
-        payload = self._get('/dns/get-zone-info.json', {'domain-name': self.domain})
+        payload = self._get('/dns/get-zone-info.json',
+                            {'domain-name': self.domain})
         self.domain_id = payload['name']
-        logger.debug('authenticate: %s', payload)
+        LOGGER.debug('authenticate: %s', payload)
 
     def create_record(self, type, name, content):
         # Skip execution if such a record already exists
@@ -54,7 +60,7 @@ class Provider(BaseProvider):
 
         # Add new record by calling the ClouDNS API
         payload = self._post('/dns/add-record.json', params)
-        logger.debug('create_record: %s', payload)
+        LOGGER.debug('create_record: %s', payload)
 
         # Error handling is already covered by self._request
         return True
@@ -82,10 +88,11 @@ class Provider(BaseProvider):
 
         # Filter by content manually as API does not support that
         if content:
-            records = [record for record in records if record['content'] == content]
+            records = [
+                record for record in records if record['content'] == content]
 
         # Print records as debug output and return them
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     def update_record(self, identifier, type=None, name=None, content=None):
@@ -110,7 +117,7 @@ class Provider(BaseProvider):
 
         # Update existing record by calling the ClouDNS API
         payload = self._post('/dns/mod-record.json', params)
-        logger.debug('update_record: %s', payload)
+        LOGGER.debug('update_record: %s', payload)
 
         # Error handling is already covered by self._request
         return True
@@ -124,20 +131,22 @@ class Provider(BaseProvider):
         else:
             delete_record_id.append(identifier)
 
-        logger.debug('delete_records: %s', delete_record_id)
+        LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
             # Delete existing record by calling the ClouDNS API
-            payload = self._post('/dns/delete-record.json', {'domain-name': self.domain_id, 'record-id': record_id})
+            payload = self._post(
+                '/dns/delete-record.json', {'domain-name': self.domain_id, 'record-id': record_id})
 
-        logger.debug('delete_record: %s', True)
+        LOGGER.debug('delete_record: %s', True)
 
         # Error handling is already covered by self._request
         return True
 
     def _build_authentication_data(self):
         if not self._get_provider_option('auth_password'):
-            raise Exception('No valid authentication data passed, expected: auth-password')
+            raise Exception(
+                'No valid authentication data passed, expected: auth-password')
 
         if self._get_provider_option('auth_id'):
             return {'auth-id': self._get_provider_option('auth_id'), 'auth-password': self._get_provider_option('auth_password')}
@@ -149,11 +158,12 @@ class Provider(BaseProvider):
             # All the options were passed with a fallback value, return an empty dictionary.
             return {}
         else:
-            raise Exception('No valid authentication data passed, expected: auth-id, auth-subid, auth-subuser')
+            raise Exception(
+                'No valid authentication data passed, expected: auth-id, auth-subid, auth-subuser')
 
     def _find_record_identifier(self, type, name, content):
         records = self.list_records(type, name, content)
-        logger.debug('records: %s', records)
+        LOGGER.debug('records: %s', records)
         if len(records) == 1:
             return records[0]['id']
         else:
@@ -171,13 +181,15 @@ class Provider(BaseProvider):
             data.update(self._build_authentication_data())
 
         # Fire request against ClouDNS API and parse result as JSON
-        r = requests.request(action, self.api_endpoint + url, params=query_params, data=data)
+        r = requests.request(action, self.api_endpoint +
+                             url, params=query_params, data=data)
         r.raise_for_status()
         payload = r.json()
 
         # Check ClouDNS specific status code and description
         if 'status' in payload and 'statusDescription' in payload and payload['status'] != 'Success':
-            raise Exception('ClouDNS API request has failed: ' + payload['statusDescription'])
+            raise Exception('ClouDNS API request has failed: ' +
+                            payload['statusDescription'])
 
         # Return payload
         return payload
